@@ -140,23 +140,30 @@ class UseTestCase(unittest.TestCase):
 
     def test_10_time_object(self):
         """Set slices using time object"""
-        item = crontab.CronItem()
+        item = crontab.CronItem(command='cmd')
         self.assertEqual(str(item.slices), '* * * * *')
         item.setall(time(1, 2))
         self.assertEqual(str(item.slices), '2 1 * * *')
+        self.assertTrue(item.is_valid())
+        item.setall(time(0, 30, 0, 0))
+        self.assertEqual(str(item.slices), '30 0 * * *')
+        self.assertTrue(item.is_valid())
+        self.assertEqual(str(item), '30 0 * * * cmd')
 
     def test_11_date_object(self):
         """Set slices using date object"""
-        item = crontab.CronItem()
+        item = crontab.CronItem(command='cmd')
         self.assertEqual(str(item.slices), '* * * * *')
         item.setall(date(2010, 6, 7))
         self.assertEqual(str(item.slices), '0 0 7 6 *')
+        self.assertTrue(item.is_valid())
 
     def test_12_datetime_object(self):
         """Set slices using datetime object"""
-        item = crontab.CronItem()
+        item = crontab.CronItem(command='cmd')
         self.assertEqual(str(item.slices), '* * * * *')
         item.setall(datetime(2009, 8, 9, 3, 4))
+        self.assertTrue(item.is_valid())
         self.assertEqual(str(item.slices), '4 3 9 8 *')
 
     def test_20_slice_validation(self):
